@@ -1,3 +1,6 @@
+# Copyright (c) Jupyter Development Team.
+# Distributed under the terms of the Modified BSD License.
+
 """Test the Settings service API.
 """
 import csv
@@ -5,14 +8,11 @@ import io
 import json
 import mimetypes
 
-import mistune
+import mistune  # type:ignore
 import pytest
 
 from jupyterlab_server import LicensesApp
-from jupyterlab_server.licenses_handler import (
-    DEFAULT_THIRD_PARTY_LICENSE_FILE,
-    LicensesManager,
-)
+from jupyterlab_server.licenses_handler import DEFAULT_THIRD_PARTY_LICENSE_FILE, LicensesManager
 
 # utilities
 
@@ -192,4 +192,4 @@ def a_licenses_manager():
 def test_labextension_bundle(a_fake_labextension, a_licenses_manager):
     ext_path, ext_name = a_fake_labextension
     bundle = a_licenses_manager.license_bundle(ext_path, ext_name)
-    assert bundle["packages"][0]["name"] == dict(FULL_ENTRY)["name"]
+    assert bundle["packages"][0]["name"] == dict(FULL_ENTRY)["name"]  # noqa
